@@ -76,8 +76,9 @@ help (FILE *where)
   fprintf (where,
     "filehash " PACKAGE_VERSION "\n"
     "usage: filehash [ -1(MD5) ] [ -2(SHA1) ] [ -3(SHA224) ] [ -4(SHA256) ]\n"
-    "         [ -5(SHA384) ] [ -6(SHA512) ] [ -f file_list ] [ -h(elp) ]\n"
-    "         [ -n byte_count ] [ -p(ipe) ] [ -q(uiet) ] [ -s(ize) ] file...\n");
+    "         [ -5(SHA384) ] [ -6(SHA512) ] [-c(lassic)] [ -f file_list ]\n"
+    "         [ -h(elp) ] [ -n byte_count ] [ -p(ipe) ] [ -q(uiet) ] [ -s(ize) ]\n"
+    "         file...\n");
 }
 
 
